.. panoramisk documentation master file, created by
   sphinx-quickstart on Thu Jan  9 12:06:32 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

=====================
:mod:`panoramisk` api
=====================

.. automodule:: panoramisk

.. autoclass:: Manager
   :members:

.. autoclass:: Action
   :members:

.. autoclass:: Message
   :members:

.. toctree::
   :maxdepth: 2

========
CHANGES
========

.. include:: ../CHANGES.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

